# Autolist

Python Basic Library for Auto-Correct purposes using lists.

**Download Autolist** : `pip install autolist`

If the above didn't work, check if Python3 is working properly.

## Examples

```python
# Import the Module
import autolist as al

# Create a list which has all the correct words OR Take input from user
correct_words_list = ["autolist","advanced","listing"]
string = "autosift" # Take input from user or Give a String

# Autolist checks the list and corrects it using the following
print(al.autocorrect_list(string, correct_words_list))
```

## Application & Features

1. **Discord Bots** :
  Where the words are auto-corrected using the given correct words list. This will help make the bot more easier and better.
2. **Python Programs** :
  Where you take input from user for a definite options but you fear that user will mistype. Autolist autochecks and corrects the mistyped word.

## Functions

- [x] autocorrect_list : Autocorrects mistyped words using the given correct words list
- [ ] autocorrect : Autocorrects words easily</li>
- [ ] accuracy_correction : Corrects words with above 90% word accuracy

_**We are ready to accept your suggestions.**_
- Message me on Discord (AbelR007#5096)
- Create an Issue in [Autolist Github](https://github.com/AbelR007/Autolist)

### Created with ❤️ by AbelR007
